============
Installation
============

At the command line::

    $ easy_install tendril-server-prefab

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv tendril
    $ pip install tendril-server-prefab
